==> education-master-1.0.1-b538.tar.gz: education-master-1.0.1-b538/src/main/java/org/rcisoft/business/blabel/service/impl/BLabelServiceImpl.java <==
package org.rcisoft.business.blabel.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blabel.dao.BLabelRepository;
import org.rcisoft.business.blabel.dto.QueryLabelResDTO;
import org.rcisoft.business.blabel.entity.BLabel;
import org.rcisoft.business.blabel.service.BLabelService;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.core.exception.ServiceException;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.result.ResultServiceEnums;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.sys.user.bean.CurUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
@Slf4j
public class BLabelServiceImpl implements BLabelService {

    @Autowired
    private BLabelRepository bLabelRepository;
    @Autowired
    private BLessonServiceImpl bLessonService;

    @Override
    public List<BLabel> queryBlabelsByPagination(PageUtil pageUtil, String lName, String corpId) {
        return bLabelRepository.queryBlabels(lName, corpId);
    }

    @Override
    public List<BLabel> queryBlabels(String lName, String corpId) {

        List<BLabel> labels = bLabelRepository.queryBlabels(lName, corpId);
        List<BLesson> lessons = bLessonService.queryHomeBLessons();
        log.info("-----------addNewLable----------首页所有课程总个数--"+lessons.size()+"--------------------");

        for (BLabel label : labels) {
            int num = 0;
            for (BLesson lesson : lessons) {
                List<QueryLabelResDTO> labelResDTOS = lesson.getLabelList();
                if (labelResDTOS.size() > 0) {
                    for (QueryLabelResDTO dto : labelResDTOS) {
                        if (dto.getBusinessId() == label.getBusinessId())
                            num++;
                    }
                }
            }
            log.info("-----------addNewLable----------当前标签--"+label+"--的new课程个数--"+num+"--------------------");
            label.setNewCount(num);
        }

        return labels;
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel insertLabel(BLabel bLabel, CurUser curUser) {
        if (StringUtils.isBlank(bLabel.getLName())) {
            throw new ServiceException("标签名称不能为空");
        }
        int line = bLabelRepository.checknameByName(bLabel.getLName(), bLabel.getBusinessId(), curUser.getCorpId());
        if (line > 0) {
            throw new ServiceException(ResultServiceEnums.NAME_IS_EXISTS);
        }
        UserUtil.setCurrentPersistOperation(bLabel);
        return new PersistModel(bLabelRepository.insert(bLabel), MessageConstant.MESSAGE_ALERT_SUCCESS);
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel updateLabel(BLabel bLabel, CurUser curUser) {
        if (StringUtils.isBlank(bLabel.getLName())) {
            throw new ServiceException("标签名称不能为空");
        }
        int line = bLabelRepository.checknameByName(bLabel.getLName(), bLabel.getBusinessId(), curUser.getCorpId());
        if (line > 0) {
            throw new ServiceException(ResultServiceEnums.NAME_IS_EXISTS);
        }
        UserUtil.setCurrentMergeOperation(bLabel);
        return new PersistModel(bLabelRepository.updateByPrimaryKeySelective(bLabel), MessageConstant.MESSAGE_ALERT_SUCCESS);
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel removeLabel(String id) {
        int line = bLabelRepository.removeLabel(id);
        return new PersistModel(line, MessageConstant.MESSAGE_ALERT_SUCCESS);
    }
}

==> education-master-1.0.2-b793.tar.gz: education-master-1.0.2-b793/src/main/java/org/rcisoft/business/blabel/service/impl/BLabelServiceImpl.java <==
package org.rcisoft.business.blabel.service.impl;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.rcisoft.business.blabel.dao.BLabelRepository;
import org.rcisoft.business.blabel.dto.QueryLabelResDTO;
import org.rcisoft.business.blabel.entity.BLabel;
import org.rcisoft.business.blabel.service.BLabelService;
import org.rcisoft.business.blesson.dao.BLessonRepository;
import org.rcisoft.business.blesson.entity.BLesson;
import org.rcisoft.business.blesson.service.impl.BLessonServiceImpl;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.constant.MessageConstant;
import org.rcisoft.core.exception.ServiceException;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.core.result.ResultServiceEnums;
import org.rcisoft.core.util.UserUtil;
import org.rcisoft.sys.user.bean.CurUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

import static java.util.Arrays.asList;

@Service
@Slf4j
public class BLabelServiceImpl implements BLabelService {

    @Autowired
    private BLabelRepository bLabelRepository;
    @Autowired
    private BLessonServiceImpl bLessonService;
    @Autowired
    private BLessonRepository bLessonRepository;

    @Override
    public List<BLabel> queryBlabelsByPagination(PageUtil pageUtil, String lName, String corpId) {
        return bLabelRepository.queryBlabels(lName, corpId);
    }

    @Override
    public List<BLabel> queryBlabels(String lName, CurUser curUser) {
        List<BLabel> labels = bLabelRepository.queryBlabels(lName, curUser.getCorpId());
        List<BLesson> lessons = addPushLable(bLessonService.queryHomeBLessons(curUser),curUser);

        log.info("-----------addNewLable----------首页所有课程总个数--"+lessons.size()+"--------------------");

        //筛选 new lesson
        List<BLesson> newLessons = new ArrayList<>();
        for(BLesson b : lessons){
            if("1".equals(b.getIsNew()))
                newLessons.add(b);
        }
        for (BLabel label : labels) {
            int num = 0;
            for (BLesson lesson : newLessons) {
                List<QueryLabelResDTO> labelResDTOS = lesson.getLabelList();
                if (labelResDTOS != null && labelResDTOS.size() > 0) {
                    for (QueryLabelResDTO dto : labelResDTOS) {
                        if (dto.getBusinessId().equals(label.getBusinessId()))
                            num++;
                    }
                }
            }
            log.info("-----------addNewLable----------当前标签--"+label+"--的new课程个数--"+num+"--------------------");
            label.setNewCount(num);
        }

        return labels;
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel insertLabel(BLabel bLabel, CurUser curUser) {
        if (StringUtils.isBlank(bLabel.getLName())) {
            throw new ServiceException("标签名称不能为空");
        }
        int line = bLabelRepository.checknameByName(bLabel.getLName(), bLabel.getBusinessId(), curUser.getCorpId());
        if (line > 0) {
            throw new ServiceException(ResultServiceEnums.NAME_IS_EXISTS);
        }
        UserUtil.setCurrentPersistOperation(bLabel);
        return new PersistModel(bLabelRepository.insert(bLabel), MessageConstant.MESSAGE_ALERT_SUCCESS);
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel updateLabel(BLabel bLabel, CurUser curUser) {
        if (StringUtils.isBlank(bLabel.getLName())) {
            throw new ServiceException("标签名称不能为空");
        }
        int line = bLabelRepository.checknameByName(bLabel.getLName(), bLabel.getBusinessId(), curUser.getCorpId());
        if (line > 0) {
            throw new ServiceException(ResultServiceEnums.NAME_IS_EXISTS);
        }
        UserUtil.setCurrentMergeOperation(bLabel);
        return new PersistModel(bLabelRepository.updateByPrimaryKeySelective(bLabel), MessageConstant.MESSAGE_ALERT_SUCCESS);
    }

    @Override
    @Transactional(propagation = Propagation.REQUIRED, readOnly = false)
    public PersistModel removeLabel(String id) {
        int line = bLabelRepository.removeLabel(id);
        return new PersistModel(line, MessageConstant.MESSAGE_ALERT_SUCCESS);
    }
    /**
     * 查询时 为知识广场的课程 添加 标签
     * @param result
     * @param curUser
     * @return
     */
    public List<BLesson> addPushLable(List<BLesson> result ,CurUser curUser){
        result.forEach(lesson->{
            List<String> list = new ArrayList<>();
            String pushLable = bLessonRepository.getPushLable(lesson.getBusinessId());
            // 获取 推荐课程的 企业自定义 标签
            List<QueryLabelResDTO> lableList = new ArrayList<>();
            if(!"###".equals(lesson.getCorpId())){
                lableList = bLessonRepository.queryLabelByLessonId(lesson.getBusinessId());
            }else {
                lableList = bLessonRepository.queryLabelByLessonId2(lesson.getBusinessId(),curUser.getCorpId());
            }
            if(StringUtils.isNotEmpty(pushLable))
                list.addAll(asList(pushLable.split(",")));
            if( list != null && list.size() > 0){
                // 加入平台推荐 标签
                lableList.addAll(bLessonRepository.queryPushLabelByLessonId(list));
            }
            lesson.setLabelList(lableList);
        });
        return result;
    }
}
